/**
  XYZ_LIB structure.
@ingroup xyzLib
*/
typedef struct XYZ_LIB
{
    /** Dealocates resourses.
    */
    void (* Destroy)(void);

    /** Returns version
    */
    int (* GetLibVersion)(void);

} XYZ_LIB;

/**
  Library entry point function.
@ingroup xyzLib
*/
XYZ_LIB* XyzLibGet(void);

/// @defgroup xyzLib Library Interface
/// @{
/// @}

/**
@mainpage Overview

  Workflow 1
  ==========

  @code

      +---------------------+
      |   Initialization    | XyzLibGet()
      +----------+----------+
                 |
      +----------+----------+
      |      Get Version    | XYZ_LIB::GetLibVersion()
      +----------+----------+
                 |
      +----------+----------+
      |  Deinitialization   | XYZ_LIB::Destroy()
      +---------------------+
  
  @endcode

  Workflow 2
  ==========

  @code

      ┌─────────────────────┐
      │   Initialization    │ XyzLibGet()
      └──────────┬──────────┘
                 │
      ┌──────────┴──────────┐
      │      Get Version    │ XYZ_LIB::GetLibVersion()
      └──────────┬──────────┘
                 │
      ┌──────────┴──────────┐
      │  Deinitialization   │ XYZ_LIB::Destroy()
      └─────────────────────┘
  
  @endcode

*/
